@@ -21,8 +21,8 @@ class BMWBackupFile(BMWFile):
 
         contents = "NBTV2"
         if os.path.exists(self._filename):
-            with open(self._filename, "rb") as source_file:
+            with open(self._filename, "r") as source_file:
                 contents = source_file.read()
 
-        with open(destination, "wb") as destination_file:
+        with open(destination, "w") as destination_file:
             destination_file.write(contents)
