@@ -1,6 +1,7 @@
 import os
 import asyncio
 import click
+from pathlib import Path
 from idrivetools.file_tools import BMWFileFactory
 """
 Take a folder containing a BMW backup and unpack it into a regular music folder
@@ -74,9 +75,7 @@ async def process_folder(source, destination, pack=True):
 @click.argument("destination", default="unpacked")
 def unpack_files(source, destination):
     click.echo(f"Unpacking from {source} to {destination}!")
-    loop = asyncio.get_event_loop()
-    loop.run_until_complete(process_folder(source, destination, False))
-    # asyncio.run(process_folder(source, destination, False))
+    asyncio.run(process_folder(source, destination, False))
 
 
 @click.command()
@@ -84,9 +83,23 @@ def unpack_files(source, destination):
 @click.argument("destination", default="packed")
 def pack_files(source, destination):
     click.echo(f"Packing from {source} to {destination}!")
-    loop = asyncio.get_event_loop()
-    loop.run_until_complete(process_folder(source, destination, True))
-    # asyncio.run(process_folder(source, destination, True))
+    asyncio.run(process_folder(source, destination, True))
+
+
+@click.command()
+@click.argument("destination", default="new_backup")
+def create_new_backup(destination):
+    click.echo(f"Creating an empty backup structure at {destination}")
+    if os.path.exists(destination):
+        click.echo("This directory already exists", err=True)
+        raise click.exceptions.Exit(-1)
+
+    Path(destination).mkdir(parents=True, exist_ok=True)
+    Path(os.path.join(destination, "Music", "USB1")).mkdir(parents=True, exist_ok=True)
+    Path(os.path.join(destination, "Music", "_Playlists")).mkdir(parents=True, exist_ok=True)
+
+    with open(os.path.join(destination, "Music", "USB1", "README.txt"), "w") as readme:
+        readme.write("Put your media files in this folder. You can make other folders too.")
 
 
 if __name__ == "__main__":
